/*
 * libsysactivity
 * http://sourceforge.net/projects/libsysactivity/
 * Copyright (c) 2009, 2010 Carlos Olmedo Escobar <carlos.olmedo.e@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <errno.h>
#include <stdlib.h>
#include "utils.h"

int get_ks(kstat_ctl_t* kc, kstat_t** ks, char* module, char* name) {
	*ks = kstat_lookup(kc, module, 0, name);
	if (*ks == NULL)
		return ENOSYS;

	if (kstat_read(kc, *ks, 0) == -1)
		return ENOSYS;

	return 0;
}

int safe_realloc(void** ptr, size_t* size) {
	void* tmp = realloc(*ptr, *size);
	if (tmp == NULL) {
		free(*ptr);
		*ptr = NULL;
		*size = 0;
		return ENOMEM;
	}
	*ptr = tmp;
	return 0;
}
